@@ -52,7 +52,7 @@ sub day_narrow          { $_[0]->day_narrows->      [ $_[1]->day_of_week_0 ] }
 
 sub am_pm               { $_[0]->am_pms->[ $_[1]->hour < 12 ? 0 : 1 ] }
 
-sub era                 { $_[0]->eras->[ $_[1]->year < 0 ? 0 : 1 ] }
+sub era                 { $_[0]->eras->[ $_[1]->ce_year < 0 ? 0 : 1 ] }
 
 sub default_date_format
 {
